package esac.archive.ehst.common.constants.client;

import java.util.EnumSet;
import java.util.HashMap;
import java.util.Map;

import esac.archive.absi.modules.common.retrievalbean.RetrievalElement;

/**
 * Utility class to store the string values used by the data distribution.
 * @author ileon
 */
public class EHstRetrievalConstants {

    /**
     * Default constructor, it should not be called.
     */
    protected EHstRetrievalConstants() {
        // prevents calls from subclass
        throw new UnsupportedOperationException();
    }

    /**
     * Retrieval element key.
     */
    public static final String RETRIEVALTYPE_KEY = RetrievalElement.RETRIEVALTYPE;

    /**
     * Retrieval element key.
     */
    public static final String RETRIEVAL_TYPE_KEY = "RETRIEVAL_TYPE";

    /**
     * Product Retrieval type.
     */
    public static final String PRODUCT_RETRIEVAL_TYPE = RetrievalElement.PRODUCT_RETRIEVALTYPE;

    /**
     * Postcard Retrieval type.
     */
    public static final String POSTCARD_RETRIEVAL_TYPE = RetrievalElement.POSTCARD_RETRIEVALTYPE;

    /**
     * Retrieval element key.
     */
    public static final String HST_OBSERVATION_ID_KEY = "HST_OBSERVATION_ID";

    /**
     * Retrieval element key.
     */
    public static final String CALIBRATION_LEVEL_KEY = "CALIBRATION_LEVEL";

    /**
     * Retrieval element key.
     */
    public static final String ARTIFACT_ID_KEY = "ARTIFACT_ID";

    /**
     * Retrieval element key.
     */
    public static final String RESOLUTION_KEY = "RESOLUTION";

    /** Default postcard resolution. */
    public static final Integer DEFAULT_POSTCARD_RESOLUTION = new Integer(1024);

    /** Low postcard resolution. */
    public static final Integer LOW_POSTCARD_RESOLUTION = new Integer(256);

    /**
     * Data retrieval Status.
     */
    public enum DataRetrievalStatusEnum {
        /** Data Retrieval Status. */
        WORKING("Working"), FINISHED("Finished"), FAILED("Failed");

        private static final Map<String, DataRetrievalOriginEnum> dataRetrievalStatusMap = new HashMap<String, DataRetrievalOriginEnum>();

        static {
            for (DataRetrievalOriginEnum dataRetrievalStatus : EnumSet
                    .allOf(DataRetrievalOriginEnum.class)) {
                dataRetrievalStatusMap.put(dataRetrievalStatus.displayValue, dataRetrievalStatus);
            }
        }
        /** Display value on the Web. */
        private final String displayValue;

        /**
         * Constructor
         * 
         * @param displayValue
         */
        DataRetrievalStatusEnum(String displayValue) {
            this.displayValue = displayValue;
        }

        public String getDisplayValue() {
            return this.displayValue;
        }

        public static DataRetrievalOriginEnum get(String displayValue) {
            return dataRetrievalStatusMap.get(displayValue);
        }

        @Override
        public String toString() {
            return this.getDisplayValue();
        }
    }

    /**
     * Data Retrieval Origin.
     */
    public enum DataRetrievalOriginEnum {
        /** Data Retrieval Origin. */
        UI("UI"), NAGIOS("NAGIOS"), AIO("AIO"), TEST("TEST");

        private static final Map<String, DataRetrievalOriginEnum> dataRetrievalOriginMap = new HashMap<String, DataRetrievalOriginEnum>();

        static {
            for (DataRetrievalOriginEnum dataRetrievalOrigin : EnumSet
                    .allOf(DataRetrievalOriginEnum.class)) {
                dataRetrievalOriginMap.put(dataRetrievalOrigin.displayValue, dataRetrievalOrigin);
            }
        }
        /** Display value on the Web. */
        private final String displayValue;

        /**
         * Constructor
         * 
         * @param displayValue
         */
        DataRetrievalOriginEnum(String displayValue) {
            this.displayValue = displayValue;
        }

        public String getDisplayValue() {
            return this.displayValue;
        }

        public static DataRetrievalOriginEnum get(String displayValue) {
            return dataRetrievalOriginMap.get(displayValue);
        }

        @Override
        public String toString() {
            return this.getDisplayValue();
        }
    }
}
