package esac.archive.ehst.common.constants.client;

/**
 * Utility class to specify HTTP constants (servlet param names, status codes, etc...) contents.
 * 
 * @author Nicolas Fajersztejn
 */
public class EhstHttpConstants {

    /**
     * Default constructor, it should not be called.
     */
    protected EhstHttpConstants() {
        // prevents calls from subclass
        throw new UnsupportedOperationException();
    }

    // Target Resolver servlet params
    public static final String SERVLET_PARAM_TARGET_NAME = "TARGET_NAME";
    public static final String SERVLET_PARAM_RESOLVER_TYPE = "RESOLVER_TYPE";

    // /////////////////////////////////////////////////////////////////////////
    // / TARGET HTTP status codes
    // /////////////////////////////////////////////////////////////////////////

    // Target Resolver Service Not Available
    public static final int STATUS_CODE_TARGET_RESOLVER_SERVICE_NOT_AVAILABLE = 998;

    // Target Not Found Status code
    public static final int STATUS_CODE_TARGET_NOT_FOUND = 999;

    // /////////////////////////////////////////////////////////////////////////
    // / CREDENTIALS HTTP status codes
    // /////////////////////////////////////////////////////////////////////////

    // Login Credentials OK
    public static final int LOGIN_CREDENTIALS_VALID = 800;

    // Login Credentials OK
    public static final int LOGOUT_OK = 801;

    // User logged in (cookie exists)
    public static final int USER_LOGGED_IN = 805;

    // Default (guest) user logged in (cookie exists)
    public static final int DEFAULT_USER_LOGGED_IN = 806;

    // Login CREDENTIALS Not valid
    public static final int LOGIN_CREDENTIALS_NOT_VALID = 810;

    // Login REQUIRED
    public static final int LOGIN_REQUIRED = 815;

    // User details update
    public static final int USER_DETAILS_UPDATED_SUCCESSFULLY = 819;
    public static final int ERROR_UPDATING_USER_DETAILS = 820;

    // User registration
    public static final int USER_REGISTRATION_OK = 821;
    public static final int USER_REGISTRATION_USER_ALREADY_EXISTS_ERROR = 822;
    public static final int USER_REGISTRATION_UNKNOWN_ERROR = 823;

    // Forgotten password
    public static final int USER_FORGOTTEN_PASSWORD_PROCESSED_OK = 830;
    public static final int USER_FORGOTTEN_PASSWORD_USERNAME_NOT_FOUND = 831;
    public static final int USER_FORGOTTEN_PASSWORD_UNKNOWN_ERROR = 832;

    // User password update
    public static final int USER_UPDATE_PASSWORD_PROCESSED_OK = 840;
    public static final int USER_UPDATE_PASSWORD_CURRENT_PASSWORD_NOT_CORRECT = 841;
    public static final int USER_UPDATE_PASSWORD_UNKWNON_ERROR = 842;

    // /////////////////////////////////////////////////////////////////////////
    // / Servlet parameters
    // /////////////////////////////////////////////////////////////////////////

    // Generic params
    public static final String SERVLET_PARAM_OBSERVATION_ID = "OBSERVATION_ID";
    public static final String SERVLET_PARAM_REVOLUTION = "REV";

    // Login servlet params
    public static final String SERVLET_PARAM_USERNAME = "USERNAME";
    public static final String SERVLET_PARAM_PASSWORD = "PASSWORD";
    public static final String SERVLET_PARAM_USER_ACTION = "SUBMIT";
    public static final String SERVLET_PARAM_USERNAME_FORGOTTEN_PASSWORD = "USERNAME_FORGOTTEN_PASSWORD";

    public static final String SERVLET_PARAM_SUBMIT_VALUE_CHECK = "CHECK";
    public static final String SERVLET_PARAM_SUBMIT_VALUE_LOGIN = "LOGIN";
    public static final String SERVLET_PARAM_SUBMIT_VALUE_LOGOUT = "LOGOUT";

    public static final String PARAM_VALUE_USER_ACTION_LOGIN = "LOGIN";
    public static final String PARAM_VALUE_USER_ACTION_LOGOUT = "LOGOUT";
    public static final String PARAM_VALUE_USER_ACTION_CHECK_USER_IS_LOGGED_IN = "CHECK";
    public static final String PARAM_VALUE_USER_ACTION_UPDATE_USER_DETAILS = "UPDATE_USER_DETAILS";
    public static final String PARAM_VALUE_USER_ACTION_UPDATE_USER_PASSWORD = "UPDATE_PASSWORD";
    public static final String PARAM_VALUE_USER_ACTION_REGISTER_NEW_USER = "REGISTER";
    public static final String PARAM_VALUE_USER_ACTION_FORGOTTEN_PASSWORD = "FORGOTTEN_PASSWORD";

    // Target List File Upload constants
    public static final String TARGET_RESOLVED_FIELD_SEPARATOR = "\t";
    public static final String TARGET_NOT_FOUND_STRING = "TARGET_NOT_FOUND";
    public static final String TARGET_WRONG_FORMAT_STRING = "TARGET_WRONG_FORMAT";

    // Coodinates List File Upload constants
    public static final String COORDINATES_WRONG_FORMAT_STRING = "COORDINATES_WRONG_FORMAT";
    public static final String RA_AND_DEC_FIELDS_SEPARATOR = ",";

    // Text to write in results file when value is null
    public static final String DEFAULT_DISPLAY_STRING_FOR_NULL_VALUE = "-";

    // Text to write in results file when value is proprietary
    public static final String DEFAULT_DISPLAY_STRING_FOR_PROPRIETARY_VALUE = "Proprietary";

    // Text to write in results file when image/icon is proprietary
    public static final String PROPRIETARY_IMAGE_STRING = "PROPRIETARY_IMAGE";

}
